==> V2.1.3.tar.gz: fe_python_trial/src/api/index.js <==
import config from '@/config'
export default {
  getProjectDetail: 'occupationlab/occupationlab/projectManage/getProjectDetail',
  submit: 'python/python/submit',
  runPythonCode: 'python/python/runPythonCode',
  queryBcJudgmentByBcId: 'judgment/judgment/bcJudgmentPoint/queryBcJudgmentByBcId',
  queryTestProject: 'occupationlab/occupationlab/projectManage/getProjectBySystemId',
  editExperimentalData: 'occupationlab/occupationlab/experimentalReport/editExperimentalData',
  queryBcJudgmentPointByBcId: 'judgment/judgment/bcJudgmentPoint/queryBcJudgmentPointByBcId',
  saveCache: 'python/python/saveCache',
  getLastCache: 'python/python/getLastCache',
  delCache: 'python/python/delCache',
  getTheMostRecentlyRunProject: 'python/python/getTheMostRecentlyRunProject',
  getDataProductBoughtByOurSchool: 'data/data/myDate/getDataProductBoughtByOurSchool',
  getPurchasedTableByCategory: `data/data/myDate/getPurchasedTableByCategory`,
  previewData: `data/data/preview`,
  lookupTableFile: `occupationlab/python/table/data/lookupTableFile`,
  downloadData:`${config.host}data/data/download`,
  fileupload: `${config.host}occupationlab/oss/manage/fileupload`,
  getDetailById: 'occupationlab/occupationlab/assessment/getDetailById',
  pageStuAssessment: 'occupationlab/occupationlab/assessment/pageStuAssessment',
  modelClassList: `nakadai/nakadai/model/reference/modelClassList`,
  referenceDemoList: `nakadai/nakadai/model/reference/demo/referenceDemoList`,
  referenceFindById: `nakadai/nakadai/model/reference/demo/findById`,
  checkIsShowBySystemId: `nakadai/nakadai/model/reference/checkIsShowBySystemId`,
  fileUpload: `${config.host}nakadai/nakadai/oss/fileUpload`,
  importData: `occupationlab/occupationlab/python/file/data/importData`,
  lookExcel: `occupationlab/occupationlab/python/file/data/lookExcel`,
  lookOver: `occupationlab/occupationlab/python/file/data/lookOver`,
  batchDeletion: `occupationlab/occupationlab/python/file/data/batchDeletion`,
  myData: `occupationlab/occupationlab/python/file/data/myData`
}

==> V2.1.7.tar.gz: fe_python_trial/src/api/index.js <==
import config from '@/config'
export default {
  getProjectDetail: 'occupationlab/occupationlab/projectManage/getProjectDetail',
  submit: 'python/python/submit',
  runPythonCode: 'python/python/runPythonCode',
  queryBcJudgmentByBcId: 'judgment/judgment/bcJudgmentPoint/queryBcJudgmentByBcId',
  queryTestProject: 'occupationlab/occupationlab/projectManage/getProjectBySystemId',
  editExperimentalData: 'occupationlab/occupationlab/experimentalReport/editExperimentalData',
  queryBcJudgmentPointByBcId: 'judgment/judgment/bcJudgmentPoint/queryBcJudgmentPointByBcId',
  saveCache: 'python/python/saveCache',
  getLastCache: 'python/python/getLastCache',
  delCache: 'python/python/delCache',
  getTheMostRecentlyRunProject: 'python/python/getTheMostRecentlyRunProject',
  getDataProductBoughtByOurSchool: 'data/data/myDate/getDataProductBoughtByOurSchool',
  getPurchasedTableByCategory: `data/data/myDate/getPurchasedTableByCategory`,
  previewData: `data/data/preview`,
  lookupTableFile: `occupationlab/python/table/data/lookupTableFile`,
  downloadData:`${config.host}data/data/download`,
  fileuploadOss: `${config.host}oss/manage/fileupload`,
  fileupload: `${config.host}occupationlab/oss/manage/fileupload`,
  getDetailById: 'occupationlab/occupationlab/assessment/getDetailById',
  pageStuAssessment: 'occupationlab/occupationlab/assessment/pageStuAssessment',
  modelClassList: `nakadai/nakadai/model/reference/modelClassList`,
  studentModelList: `nakadai/nakadai/model/student/studentModelList`,
  referenceDemoList: `nakadai/nakadai/model/reference/demo/referenceDemoList`,
  referenceFindById: `nakadai/nakadai/model/reference/demo/findById`,
  checkIsShowBySystemId: `nakadai/nakadai/model/reference/checkIsShowBySystemId`,
  fileUpload: `${config.host}nakadai/nakadai/oss/fileUpload`,
  importData: `occupationlab/occupationlab/python/file/data/importData`,
  lookExcel: `occupationlab/occupationlab/python/file/data/lookExcel`,
  lookOver: `occupationlab/occupationlab/python/file/data/lookOver`,
  batchDeletion: `occupationlab/occupationlab/python/file/data/batchDeletion`,
  myData: `occupationlab/occupationlab/python/file/data/myData`,
  updateReport: `occupationlab/occupationlab/achievement/updateReport`,
  exportLabReport: `occupationlab/occupationlab/achievement/exportLabReport`,
  reportDetail: `occupationlab/occupationlab/achievement/reportDetail`,
  getCompetition: `competition/competition/management/getCompetition`,
	whetherCanPaste: `nakadai/nakadai/model/demo/whetherCanPaste`,
	displayListOrNotByStudent: `nakadai/nakadai/model/demo/displayListOrNotByStudent`,
	modelClassListByStudent: `nakadai/nakadai/model/student/modelClassListByStudent`,
	studentModelListBySystem: `nakadai/nakadai/model/student/studentModelListBySystem`,
	detailsOfGoods: `nakadai/mall/detailsOfGoods`,
}
